@@ -44,7 +44,8 @@ EXTERN_VAR monf stcmem, radmem;
 EXTERN_VAR int hisModule;
 EXTERN_VAR monf stcmem, radmem;
 EXTERN_VAR indset ISet, JSet;
-EXTERN_VAR int  hCo, hMu, hMu2;
+EXTERN_VAR int  hCo, hMu2;
+EXTERN_VAR long  hMu;
 
 
 void hDelete(scfmon ev, int ev_length);
@@ -78,7 +79,7 @@ void hIndAllMult(scmon pure, int Npure, scfmon rad, int Nrad,
 void hDegreeSeries(intvec *s1, intvec *s2, int *co, int *mu);
 
 
-scfmon hInit(ideal S, ideal Q, int * Nexist, ring tailRing);
+scfmon hInit(ideal S, ideal Q, int * Nexist);
 void slicehilb(ideal I);
 void HilbertSeries_OrbitData(ideal S, int lV, bool ig, bool mgrad, bool odp, int trunDegHs);
 ideal  RightColonOperation(ideal i, poly w, int lV);
